.. django Organice documentation master file, created by sphinx-quickstart on Thu Feb 20 23:16:50 2014.
   You can adapt this file completely to your liking, but it should at least contain the root `toctree` directive.

=========================================
Welcome to django Organice documentation!
=========================================

Contents:

.. toctree::
   :maxdepth: 2

   overview
   installation
   components
   contributing
   alternatives
   changelog


==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
